@@ -77,33 +77,32 @@ static void usage(const char *name, int exit_code)
 {
 	fprintf(exit_code ? stderr : stdout,
 		"  Usage: %s [-%s] [ context | - ]\n"
-		"          --help        -h     Show this message.\n"
-		"          --version     -V     Show the version.\n"
-		"          --prompt      -P     Output in a format good for a prompt.\n"
-		"          --user        -u     Show the user of the context.\n"
-		"          --role        -r     Show the role of the context.\n"
-		"          --type        -t     Show the type of the context.\n"
-		"          --sensitivity -s     Show the sensitivity level of the context.\n"
-		"          --clearance   -c     Show the clearance level of the context.\n"
-		"          --mls-range   -m     Show the sensitivity to clearance range of \n"
-		"                               the context.\n"
-		"          --raw         -R     Show the context in \"raw\" format.\n"
-		"          --color       -C     Output using ANSI color codes (requires -P).\n"
-		"          --current            Get the context for the current process.\n"
-		"          --self               Get the context for the current process.\n"
-		"          --self-exec          Get the exec context for the current process.\n"
-		"          --self-fs            Get the fs context for the current process.\n"
-		"          --self-key           Get the key context for the current process.\n"
-		"          --parent             Get the context for the parent process.\n"
-		"          --parent-exec        Get the exec context for the parent process.\n"
-		"          --parent-fs          Get the fs context for the parent process.\n"
-		"          --parent-key         Get the key context for the parent process.\n"
-		"          --pid       -p <arg> Use the context from the specified pid.\n"
-		"          --pid-exec     <arg> Use the exec context from the specified pid.\n"
-		"          --pid-fs       <arg> Use the fs context from the specified pid.\n"
-		"          --pid-key      <arg> Use the key context from the specified pid.\n"
-		"          --file      -f <arg> Use the context from the specified file.\n"
-		"          --link      -L <arg> Use the context from the specified link.\n",
+		"          --help          -h            Show this message.\n"
+		"          --version       -V            Show the version.\n"
+		"          --prompt        -P            Output in a format good for a prompt.\n"
+		"          --user          -u            Show the user of the context.\n"
+		"          --role          -r            Show the role of the context.\n"
+		"          --type          -t            Show the type of the context.\n"
+		"          --sensitivity   -s            Show the sensitivity level of the context.\n"
+		"          --clearance     -c            Show the clearance level of the context.\n"
+		"          --mls-range     -m            Show the sensitivity to clearance range of \n"
+		"                                        the context.\n"
+		"          --raw           -R            Show the context in \"raw\" format.\n"
+		"          --color         -C            Output using ANSI color codes (requires -P).\n"
+		"          --current,      --self        Get the context for the current process.\n"
+		"          --current-exec, --self-exec   Get the exec context for the current process.\n"
+		"          --current-fs,   --self-fs     Get the fs context for the current process.\n"
+		"          --current-key,  --self-key    Get the key context for the current process.\n"
+		"          --parent                      Get the context for the parent process.\n"
+		"          --parent-exec                 Get the exec context for the parent process.\n"
+		"          --parent-fs                   Get the fs context for the parent process.\n"
+		"          --parent-key                  Get the key context for the parent process.\n"
+		"          --pid           -p <arg>      Use the context from the specified pid.\n"
+		"          --pid-exec      <arg>         Use the exec context from the specified pid.\n"
+		"          --pid-fs        <arg>         Use the fs context from the specified pid.\n"
+		"          --pid-key       <arg>         Use the key context from the specified pid.\n"
+		"          --file          -f <arg>      Use the context from the specified file.\n"
+		"          --link          -L <arg>      Use the context from the specified link.\n",
 		name, SECON_OPTS_SM);
 
 	exit(exit_code);
